### Data Creation |
* | Mandatory fields

#### Step 1*

DataStore *

#### Step 2* |

Name *
Short Description *

Public | Restricted | Private

#### Step 3 |

Agent Type
Topic
Data Type

Raw Processed Mixed

Licence ( CC versionL 4.0 )

| Public Domain |
| CC-0 |
| PDDL |
| CC-BY |
| ODC-BY |
| CC-BY-SA |
| ODC-ODbL |
| CC BY-NC |
| CC BY-ND |
| CC BY-NC-SA |
| CC BY-NC-ND |
| Other

### Asking for Datastores Access

None